# Introducción
Arquitectura basada en Python utilizada como navaja suiza para pequeñas o grandes aplicaciones

Lista de herramientas proporcionadas:
- Logging
- Configuración
- Dockers
- API REST
- Cache (REDIS)
- Concurrencia

# Funcionalidades actuales
[Enlace a ejemplos de uso](https://www.notion.so/ce7410e76b204446ae114a9ccb5cb09a?v=39826cf8d6014f2f8c2ddf38d9f72272)